#! /bin/sh

## Verbose mode
test "x$VERBOSE" = xx && set -x

## Checks ncbi very very large blast output
../html4blast -g -o trunc.html ${srcdir}/trunc.blast

